@@ -522,7 +522,8 @@ xnat_connect <- function(base_url, username=NULL, password=NULL, xnat_name=NULL)
                            scan_type = NULL,
                            zipped = TRUE,
                            verbose = FALSE,
-                           error = FALSE){
+                           error = FALSE, 
+                           extract = FALSE){
     if(is.null(file_dir)) {
       file_dir <- tempdir()
     }
@@ -554,6 +555,13 @@ xnat_connect <- function(base_url, username=NULL, password=NULL, xnat_name=NULL)
         stop_for_status(ret)
       }
       if(ret$status_code == "200") {
+        if(extract)
+        {
+          unzip(destfile, exdir=tempdir())
+          unzipped_destfile <- unzip(destfile, list=TRUE) 
+          zipfile <- file.path(tempdir(),unzipped_destfile$Name)
+          return(zipfile)
+        }
         return(destfile)
       }
       else {
@@ -724,15 +732,18 @@ download_xnat_file = function(conn, ...){
 #'   zipped zip the downloaded result
 #'   verbose Should progress be added to download?
 #'   error Should function error if download failed?
+#'   extract Unzip the result and return the files list (based on scan_type)
 #' 
 #' @return Display path to the downloaded file
 #' @importFrom httr stop_for_status write_disk progress GET
+#' @importFrom utils unzip
 #' @examples
 #' \dontrun{nitrc <- xnat_connect('https://nitrc.org/ir', xnat_name='NITRC')}
 #' \dontrun{download_xnat_dir(nitrc, 
 #'                            experiment_ID='NITRC_IR_E10507',
 #'                            scan_type='T2', 
-#'                            file_dir = tempdir())
+#'                            file_dir = tempdir(),
+#'                            extract = TRUE)
 #' }
 #' @export
 download_xnat_dir = function(conn, ...){
